@@ -12,14 +12,14 @@ import tempfile
 import threading
 import time
 
-if sys.version_info < (3, 0):
-    from future_builtins import zip
-    range = xrange
-
 import pytest
 
 import plyvel
 
+if sys.version_info < (3, 0):
+    from future_builtins import zip
+    range = xrange  # noqa: F821 (python 2 only)
+
 
 #
 # Fixtures
@@ -222,6 +222,18 @@ def test_null_bytes(db):
     assert db.get(key) is None
 
 
+def test_bytes_like(db):
+    b = b'bar'
+
+    value = bytearray(b)
+    db.put(b'quux', value)
+    assert db.get(b'quux') == value
+
+    value = memoryview(b)
+    db.put(b'foo', value)
+    assert db.get(b'foo') == value
+
+
 def test_write_batch(db):
     # Prepare a batch with some data
     batch = db.write_batch()
@@ -278,6 +290,14 @@ def test_write_batch_transaction(db):
     assert list(db.iterator()) == []
 
 
+def test_write_batch_bytes_like(db):
+    with db.write_batch() as wb:
+        wb.put(b'a', bytearray(b'foo'))
+        wb.put(b'b', memoryview(b'bar'))
+    assert db.get(b'a') == b'foo'
+    assert db.get(b'b') == b'bar'
+
+
 def test_iteration(db):
     entries = []
     for i in range(100):
